# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .annotation import (
    Annotation,
)
from .annotation_spec import (
    AnnotationSpec,
)
from .artifact import (
    Artifact,
)
from .batch_prediction_job import (
    BatchPredictionJob,
)
from .completion_stats import (
    CompletionStats,
)
from .context import (
    Context,
)
from .custom_job import (
    ContainerSpec,
    CustomJob,
    CustomJobSpec,
    PythonPackageSpec,
    Scheduling,
    WorkerPoolSpec,
)
from .data_item import (
    DataItem,
)
from .data_labeling_job import (
    ActiveLearningConfig,
    DataLabelingJob,
    SampleConfig,
    TrainingConfig,
)
from .dataset import (
    Dataset,
    ExportDataConfig,
    ImportDataConfig,
)
from .dataset_service import (
    CreateDatasetOperationMetadata,
    CreateDatasetRequest,
    DataItemView,
    DeleteDatasetRequest,
    ExportDataOperationMetadata,
    ExportDataRequest,
    ExportDataResponse,
    GetAnnotationSpecRequest,
    GetDatasetRequest,
    ImportDataOperationMetadata,
    ImportDataRequest,
    ImportDataResponse,
    ListAnnotationsRequest,
    ListAnnotationsResponse,
    ListDataItemsRequest,
    ListDataItemsResponse,
    ListDatasetsRequest,
    ListDatasetsResponse,
    ListSavedQueriesRequest,
    ListSavedQueriesResponse,
    SearchDataItemsRequest,
    SearchDataItemsResponse,
    UpdateDatasetRequest,
)
from .deployed_index_ref import (
    DeployedIndexRef,
)
from .deployed_model_ref import (
    DeployedModelRef,
)
from .encryption_spec import (
    EncryptionSpec,
)
from .endpoint import (
    DeployedModel,
    Endpoint,
    PredictRequestResponseLoggingConfig,
    PrivateEndpoints,
)
from .endpoint_service import (
    CreateEndpointOperationMetadata,
    CreateEndpointRequest,
    DeleteEndpointRequest,
    DeployModelOperationMetadata,
    DeployModelRequest,
    DeployModelResponse,
    GetEndpointRequest,
    ListEndpointsRequest,
    ListEndpointsResponse,
    UndeployModelOperationMetadata,
    UndeployModelRequest,
    UndeployModelResponse,
    UpdateEndpointRequest,
)
from .entity_type import (
    EntityType,
)
from .env_var import (
    EnvVar,
)
from .event import (
    Event,
)
from .execution import (
    Execution,
)
from .explanation import (
    Attribution,
    BlurBaselineConfig,
    ExamplesOverride,
    ExamplesRestrictionsNamespace,
    Explanation,
    ExplanationMetadataOverride,
    ExplanationParameters,
    ExplanationSpec,
    ExplanationSpecOverride,
    FeatureNoiseSigma,
    IntegratedGradientsAttribution,
    ModelExplanation,
    Neighbor,
    SampledShapleyAttribution,
    SmoothGradConfig,
    XraiAttribution,
)
from .explanation_metadata import (
    ExplanationMetadata,
)
from .feature import (
    Feature,
)
from .feature_monitoring_stats import (
    FeatureStatsAnomaly,
)
from .feature_selector import (
    FeatureSelector,
    IdMatcher,
)
from .featurestore import (
    Featurestore,
)
from .featurestore_monitoring import (
    FeaturestoreMonitoringConfig,
)
from .featurestore_online_service import (
    FeatureValue,
    FeatureValueList,
    ReadFeatureValuesRequest,
    ReadFeatureValuesResponse,
    StreamingReadFeatureValuesRequest,
    WriteFeatureValuesPayload,
    WriteFeatureValuesRequest,
    WriteFeatureValuesResponse,
)
from .featurestore_service import (
    BatchCreateFeaturesOperationMetadata,
    BatchCreateFeaturesRequest,
    BatchCreateFeaturesResponse,
    BatchReadFeatureValuesOperationMetadata,
    BatchReadFeatureValuesRequest,
    BatchReadFeatureValuesResponse,
    CreateEntityTypeOperationMetadata,
    CreateEntityTypeRequest,
    CreateFeatureOperationMetadata,
    CreateFeatureRequest,
    CreateFeaturestoreOperationMetadata,
    CreateFeaturestoreRequest,
    DeleteEntityTypeRequest,
    DeleteFeatureRequest,
    DeleteFeaturestoreRequest,
    DestinationFeatureSetting,
    ExportFeatureValuesOperationMetadata,
    ExportFeatureValuesRequest,
    ExportFeatureValuesResponse,
    FeatureValueDestination,
    GetEntityTypeRequest,
    GetFeatureRequest,
    GetFeaturestoreRequest,
    ImportFeatureValuesOperationMetadata,
    ImportFeatureValuesRequest,
    ImportFeatureValuesResponse,
    ListEntityTypesRequest,
    ListEntityTypesResponse,
    ListFeaturesRequest,
    ListFeaturesResponse,
    ListFeaturestoresRequest,
    ListFeaturestoresResponse,
    SearchFeaturesRequest,
    SearchFeaturesResponse,
    UpdateEntityTypeRequest,
    UpdateFeatureRequest,
    UpdateFeaturestoreOperationMetadata,
    UpdateFeaturestoreRequest,
)
from .hyperparameter_tuning_job import (
    HyperparameterTuningJob,
)
from .index import (
    Index,
    IndexDatapoint,
    IndexStats,
)
from .index_endpoint import (
    DeployedIndex,
    DeployedIndexAuthConfig,
    IndexEndpoint,
    IndexPrivateEndpoints,
)
from .index_endpoint_service import (
    CreateIndexEndpointOperationMetadata,
    CreateIndexEndpointRequest,
    DeleteIndexEndpointRequest,
    DeployIndexOperationMetadata,
    DeployIndexRequest,
    DeployIndexResponse,
    GetIndexEndpointRequest,
    ListIndexEndpointsRequest,
    ListIndexEndpointsResponse,
    MutateDeployedIndexOperationMetadata,
    MutateDeployedIndexRequest,
    MutateDeployedIndexResponse,
    UndeployIndexOperationMetadata,
    UndeployIndexRequest,
    UndeployIndexResponse,
    UpdateIndexEndpointRequest,
)
from .index_service import (
    CreateIndexOperationMetadata,
    CreateIndexRequest,
    DeleteIndexRequest,
    GetIndexRequest,
    ListIndexesRequest,
    ListIndexesResponse,
    NearestNeighborSearchOperationMetadata,
    RemoveDatapointsRequest,
    RemoveDatapointsResponse,
    UpdateIndexOperationMetadata,
    UpdateIndexRequest,
    UpsertDatapointsRequest,
    UpsertDatapointsResponse,
)
from .io import (
    AvroSource,
    BigQueryDestination,
    BigQuerySource,
    ContainerRegistryDestination,
    CsvDestination,
    CsvSource,
    GcsDestination,
    GcsSource,
    TFRecordDestination,
)
from .job_service import (
    CancelBatchPredictionJobRequest,
    CancelCustomJobRequest,
    CancelDataLabelingJobRequest,
    CancelHyperparameterTuningJobRequest,
    CancelNasJobRequest,
    CreateBatchPredictionJobRequest,
    CreateCustomJobRequest,
    CreateDataLabelingJobRequest,
    CreateHyperparameterTuningJobRequest,
    CreateModelDeploymentMonitoringJobRequest,
    CreateNasJobRequest,
    DeleteBatchPredictionJobRequest,
    DeleteCustomJobRequest,
    DeleteDataLabelingJobRequest,
    DeleteHyperparameterTuningJobRequest,
    DeleteModelDeploymentMonitoringJobRequest,
    DeleteNasJobRequest,
    GetBatchPredictionJobRequest,
    GetCustomJobRequest,
    GetDataLabelingJobRequest,
    GetHyperparameterTuningJobRequest,
    GetModelDeploymentMonitoringJobRequest,
    GetNasJobRequest,
    GetNasTrialDetailRequest,
    ListBatchPredictionJobsRequest,
    ListBatchPredictionJobsResponse,
    ListCustomJobsRequest,
    ListCustomJobsResponse,
    ListDataLabelingJobsRequest,
    ListDataLabelingJobsResponse,
    ListHyperparameterTuningJobsRequest,
    ListHyperparameterTuningJobsResponse,
    ListModelDeploymentMonitoringJobsRequest,
    ListModelDeploymentMonitoringJobsResponse,
    ListNasJobsRequest,
    ListNasJobsResponse,
    ListNasTrialDetailsRequest,
    ListNasTrialDetailsResponse,
    PauseModelDeploymentMonitoringJobRequest,
    ResumeModelDeploymentMonitoringJobRequest,
    SearchModelDeploymentMonitoringStatsAnomaliesRequest,
    SearchModelDeploymentMonitoringStatsAnomaliesResponse,
    UpdateModelDeploymentMonitoringJobOperationMetadata,
    UpdateModelDeploymentMonitoringJobRequest,
)
from .lineage_subgraph import (
    LineageSubgraph,
)
from .machine_resources import (
    AutomaticResources,
    AutoscalingMetricSpec,
    BatchDedicatedResources,
    DedicatedResources,
    DiskSpec,
    MachineSpec,
    NfsMount,
    ResourcesConsumed,
)
from .manual_batch_tuning_parameters import (
    ManualBatchTuningParameters,
)
from .metadata_schema import (
    MetadataSchema,
)
from .metadata_service import (
    AddContextArtifactsAndExecutionsRequest,
    AddContextArtifactsAndExecutionsResponse,
    AddContextChildrenRequest,
    AddContextChildrenResponse,
    AddExecutionEventsRequest,
    AddExecutionEventsResponse,
    CreateArtifactRequest,
    CreateContextRequest,
    CreateExecutionRequest,
    CreateMetadataSchemaRequest,
    CreateMetadataStoreOperationMetadata,
    CreateMetadataStoreRequest,
    DeleteArtifactRequest,
    DeleteContextRequest,
    DeleteExecutionRequest,
    DeleteMetadataStoreOperationMetadata,
    DeleteMetadataStoreRequest,
    GetArtifactRequest,
    GetContextRequest,
    GetExecutionRequest,
    GetMetadataSchemaRequest,
    GetMetadataStoreRequest,
    ListArtifactsRequest,
    ListArtifactsResponse,
    ListContextsRequest,
    ListContextsResponse,
    ListExecutionsRequest,
    ListExecutionsResponse,
    ListMetadataSchemasRequest,
    ListMetadataSchemasResponse,
    ListMetadataStoresRequest,
    ListMetadataStoresResponse,
    PurgeArtifactsMetadata,
    PurgeArtifactsRequest,
    PurgeArtifactsResponse,
    PurgeContextsMetadata,
    PurgeContextsRequest,
    PurgeContextsResponse,
    PurgeExecutionsMetadata,
    PurgeExecutionsRequest,
    PurgeExecutionsResponse,
    QueryArtifactLineageSubgraphRequest,
    QueryContextLineageSubgraphRequest,
    QueryExecutionInputsAndOutputsRequest,
    RemoveContextChildrenRequest,
    RemoveContextChildrenResponse,
    UpdateArtifactRequest,
    UpdateContextRequest,
    UpdateExecutionRequest,
)
from .metadata_store import (
    MetadataStore,
)
from .migratable_resource import (
    MigratableResource,
)
from .migration_service import (
    BatchMigrateResourcesOperationMetadata,
    BatchMigrateResourcesRequest,
    BatchMigrateResourcesResponse,
    MigrateResourceRequest,
    MigrateResourceResponse,
    SearchMigratableResourcesRequest,
    SearchMigratableResourcesResponse,
)
from .model import (
    Model,
    ModelContainerSpec,
    ModelSourceInfo,
    Port,
    PredictSchemata,
)
from .model_deployment_monitoring_job import (
    ModelDeploymentMonitoringBigQueryTable,
    ModelDeploymentMonitoringJob,
    ModelDeploymentMonitoringObjectiveConfig,
    ModelDeploymentMonitoringScheduleConfig,
    ModelMonitoringStatsAnomalies,
    ModelDeploymentMonitoringObjectiveType,
)
from .model_evaluation import (
    ModelEvaluation,
)
from .model_evaluation_slice import (
    ModelEvaluationSlice,
)
from .model_monitoring import (
    ModelMonitoringAlertConfig,
    ModelMonitoringObjectiveConfig,
    SamplingStrategy,
    ThresholdConfig,
)
from .model_service import (
    BatchImportModelEvaluationSlicesRequest,
    BatchImportModelEvaluationSlicesResponse,
    CopyModelOperationMetadata,
    CopyModelRequest,
    CopyModelResponse,
    DeleteModelRequest,
    DeleteModelVersionRequest,
    ExportModelOperationMetadata,
    ExportModelRequest,
    ExportModelResponse,
    GetModelEvaluationRequest,
    GetModelEvaluationSliceRequest,
    GetModelRequest,
    ImportModelEvaluationRequest,
    ListModelEvaluationSlicesRequest,
    ListModelEvaluationSlicesResponse,
    ListModelEvaluationsRequest,
    ListModelEvaluationsResponse,
    ListModelsRequest,
    ListModelsResponse,
    ListModelVersionsRequest,
    ListModelVersionsResponse,
    MergeVersionAliasesRequest,
    UpdateModelRequest,
    UploadModelOperationMetadata,
    UploadModelRequest,
    UploadModelResponse,
)
from .nas_job import (
    NasJob,
    NasJobOutput,
    NasJobSpec,
    NasTrial,
    NasTrialDetail,
)
from .operation import (
    DeleteOperationMetadata,
    GenericOperationMetadata,
)
from .pipeline_job import (
    PipelineJob,
    PipelineJobDetail,
    PipelineTaskDetail,
    PipelineTaskExecutorDetail,
    PipelineTemplateMetadata,
)
from .pipeline_service import (
    CancelPipelineJobRequest,
    CancelTrainingPipelineRequest,
    CreatePipelineJobRequest,
    CreateTrainingPipelineRequest,
    DeletePipelineJobRequest,
    DeleteTrainingPipelineRequest,
    GetPipelineJobRequest,
    GetTrainingPipelineRequest,
    ListPipelineJobsRequest,
    ListPipelineJobsResponse,
    ListTrainingPipelinesRequest,
    ListTrainingPipelinesResponse,
)
from .prediction_service import (
    ExplainRequest,
    ExplainResponse,
    PredictRequest,
    PredictResponse,
    RawPredictRequest,
)
from .saved_query import (
    SavedQuery,
)
from .service_networking import (
    PrivateServiceConnectConfig,
)
from .specialist_pool import (
    SpecialistPool,
)
from .specialist_pool_service import (
    CreateSpecialistPoolOperationMetadata,
    CreateSpecialistPoolRequest,
    DeleteSpecialistPoolRequest,
    GetSpecialistPoolRequest,
    ListSpecialistPoolsRequest,
    ListSpecialistPoolsResponse,
    UpdateSpecialistPoolOperationMetadata,
    UpdateSpecialistPoolRequest,
)
from .study import (
    Measurement,
    Study,
    StudySpec,
    Trial,
)
from .tensorboard import (
    Tensorboard,
)
from .tensorboard_data import (
    Scalar,
    TensorboardBlob,
    TensorboardBlobSequence,
    TensorboardTensor,
    TimeSeriesData,
    TimeSeriesDataPoint,
)
from .tensorboard_experiment import (
    TensorboardExperiment,
)
from .tensorboard_run import (
    TensorboardRun,
)
from .tensorboard_service import (
    BatchCreateTensorboardRunsRequest,
    BatchCreateTensorboardRunsResponse,
    BatchCreateTensorboardTimeSeriesRequest,
    BatchCreateTensorboardTimeSeriesResponse,
    BatchReadTensorboardTimeSeriesDataRequest,
    BatchReadTensorboardTimeSeriesDataResponse,
    CreateTensorboardExperimentRequest,
    CreateTensorboardOperationMetadata,
    CreateTensorboardRequest,
    CreateTensorboardRunRequest,
    CreateTensorboardTimeSeriesRequest,
    DeleteTensorboardExperimentRequest,
    DeleteTensorboardRequest,
    DeleteTensorboardRunRequest,
    DeleteTensorboardTimeSeriesRequest,
    ExportTensorboardTimeSeriesDataRequest,
    ExportTensorboardTimeSeriesDataResponse,
    GetTensorboardExperimentRequest,
    GetTensorboardRequest,
    GetTensorboardRunRequest,
    GetTensorboardTimeSeriesRequest,
    ListTensorboardExperimentsRequest,
    ListTensorboardExperimentsResponse,
    ListTensorboardRunsRequest,
    ListTensorboardRunsResponse,
    ListTensorboardsRequest,
    ListTensorboardsResponse,
    ListTensorboardTimeSeriesRequest,
    ListTensorboardTimeSeriesResponse,
    ReadTensorboardBlobDataRequest,
    ReadTensorboardBlobDataResponse,
    ReadTensorboardTimeSeriesDataRequest,
    ReadTensorboardTimeSeriesDataResponse,
    ReadTensorboardUsageRequest,
    ReadTensorboardUsageResponse,
    UpdateTensorboardExperimentRequest,
    UpdateTensorboardOperationMetadata,
    UpdateTensorboardRequest,
    UpdateTensorboardRunRequest,
    UpdateTensorboardTimeSeriesRequest,
    WriteTensorboardExperimentDataRequest,
    WriteTensorboardExperimentDataResponse,
    WriteTensorboardRunDataRequest,
    WriteTensorboardRunDataResponse,
)
from .tensorboard_time_series import (
    TensorboardTimeSeries,
)
from .training_pipeline import (
    FilterSplit,
    FractionSplit,
    InputDataConfig,
    PredefinedSplit,
    StratifiedSplit,
    TimestampSplit,
    TrainingPipeline,
)
from .types import (
    BoolArray,
    DoubleArray,
    Int64Array,
    StringArray,
)
from .unmanaged_container_model import (
    UnmanagedContainerModel,
)
from .user_action_reference import (
    UserActionReference,
)
from .value import (
    Value,
)
from .vizier_service import (
    AddTrialMeasurementRequest,
    CheckTrialEarlyStoppingStateMetatdata,
    CheckTrialEarlyStoppingStateRequest,
    CheckTrialEarlyStoppingStateResponse,
    CompleteTrialRequest,
    CreateStudyRequest,
    CreateTrialRequest,
    DeleteStudyRequest,
    DeleteTrialRequest,
    GetStudyRequest,
    GetTrialRequest,
    ListOptimalTrialsRequest,
    ListOptimalTrialsResponse,
    ListStudiesRequest,
    ListStudiesResponse,
    ListTrialsRequest,
    ListTrialsResponse,
    LookupStudyRequest,
    StopTrialRequest,
    SuggestTrialsMetadata,
    SuggestTrialsRequest,
    SuggestTrialsResponse,
)

__all__ = (
    "AcceleratorType",
    "Annotation",
    "AnnotationSpec",
    "Artifact",
    "BatchPredictionJob",
    "CompletionStats",
    "Context",
    "ContainerSpec",
    "CustomJob",
    "CustomJobSpec",
    "PythonPackageSpec",
    "Scheduling",
    "WorkerPoolSpec",
    "DataItem",
    "ActiveLearningConfig",
    "DataLabelingJob",
    "SampleConfig",
    "TrainingConfig",
    "Dataset",
    "ExportDataConfig",
    "ImportDataConfig",
    "CreateDatasetOperationMetadata",
    "CreateDatasetRequest",
    "DataItemView",
    "DeleteDatasetRequest",
    "ExportDataOperationMetadata",
    "ExportDataRequest",
    "ExportDataResponse",
    "GetAnnotationSpecRequest",
    "GetDatasetRequest",
    "ImportDataOperationMetadata",
    "ImportDataRequest",
    "ImportDataResponse",
    "ListAnnotationsRequest",
    "ListAnnotationsResponse",
    "ListDataItemsRequest",
    "ListDataItemsResponse",
    "ListDatasetsRequest",
    "ListDatasetsResponse",
    "ListSavedQueriesRequest",
    "ListSavedQueriesResponse",
    "SearchDataItemsRequest",
    "SearchDataItemsResponse",
    "UpdateDatasetRequest",
    "DeployedIndexRef",
    "DeployedModelRef",
    "EncryptionSpec",
    "DeployedModel",
    "Endpoint",
    "PredictRequestResponseLoggingConfig",
    "PrivateEndpoints",
    "CreateEndpointOperationMetadata",
    "CreateEndpointRequest",
    "DeleteEndpointRequest",
    "DeployModelOperationMetadata",
    "DeployModelRequest",
    "DeployModelResponse",
    "GetEndpointRequest",
    "ListEndpointsRequest",
    "ListEndpointsResponse",
    "UndeployModelOperationMetadata",
    "UndeployModelRequest",
    "UndeployModelResponse",
    "UpdateEndpointRequest",
    "EntityType",
    "EnvVar",
    "Event",
    "Execution",
    "Attribution",
    "BlurBaselineConfig",
    "ExamplesOverride",
    "ExamplesRestrictionsNamespace",
    "Explanation",
    "ExplanationMetadataOverride",
    "ExplanationParameters",
    "ExplanationSpec",
    "ExplanationSpecOverride",
    "FeatureNoiseSigma",
    "IntegratedGradientsAttribution",
    "ModelExplanation",
    "Neighbor",
    "SampledShapleyAttribution",
    "SmoothGradConfig",
    "XraiAttribution",
    "ExplanationMetadata",
    "Feature",
    "FeatureStatsAnomaly",
    "FeatureSelector",
    "IdMatcher",
    "Featurestore",
    "FeaturestoreMonitoringConfig",
    "FeatureValue",
    "FeatureValueList",
    "ReadFeatureValuesRequest",
    "ReadFeatureValuesResponse",
    "StreamingReadFeatureValuesRequest",
    "WriteFeatureValuesPayload",
    "WriteFeatureValuesRequest",
    "WriteFeatureValuesResponse",
    "BatchCreateFeaturesOperationMetadata",
    "BatchCreateFeaturesRequest",
    "BatchCreateFeaturesResponse",
    "BatchReadFeatureValuesOperationMetadata",
    "BatchReadFeatureValuesRequest",
    "BatchReadFeatureValuesResponse",
    "CreateEntityTypeOperationMetadata",
    "CreateEntityTypeRequest",
    "CreateFeatureOperationMetadata",
    "CreateFeatureRequest",
    "CreateFeaturestoreOperationMetadata",
    "CreateFeaturestoreRequest",
    "DeleteEntityTypeRequest",
    "DeleteFeatureRequest",
    "DeleteFeaturestoreRequest",
    "DestinationFeatureSetting",
    "ExportFeatureValuesOperationMetadata",
    "ExportFeatureValuesRequest",
    "ExportFeatureValuesResponse",
    "FeatureValueDestination",
    "GetEntityTypeRequest",
    "GetFeatureRequest",
    "GetFeaturestoreRequest",
    "ImportFeatureValuesOperationMetadata",
    "ImportFeatureValuesRequest",
    "ImportFeatureValuesResponse",
    "ListEntityTypesRequest",
    "ListEntityTypesResponse",
    "ListFeaturesRequest",
    "ListFeaturesResponse",
    "ListFeaturestoresRequest",
    "ListFeaturestoresResponse",
    "SearchFeaturesRequest",
    "SearchFeaturesResponse",
    "UpdateEntityTypeRequest",
    "UpdateFeatureRequest",
    "UpdateFeaturestoreOperationMetadata",
    "UpdateFeaturestoreRequest",
    "HyperparameterTuningJob",
    "Index",
    "IndexDatapoint",
    "IndexStats",
    "DeployedIndex",
    "DeployedIndexAuthConfig",
    "IndexEndpoint",
    "IndexPrivateEndpoints",
    "CreateIndexEndpointOperationMetadata",
    "CreateIndexEndpointRequest",
    "DeleteIndexEndpointRequest",
    "DeployIndexOperationMetadata",
    "DeployIndexRequest",
    "DeployIndexResponse",
    "GetIndexEndpointRequest",
    "ListIndexEndpointsRequest",
    "ListIndexEndpointsResponse",
    "MutateDeployedIndexOperationMetadata",
    "MutateDeployedIndexRequest",
    "MutateDeployedIndexResponse",
    "UndeployIndexOperationMetadata",
    "UndeployIndexRequest",
    "UndeployIndexResponse",
    "UpdateIndexEndpointRequest",
    "CreateIndexOperationMetadata",
    "CreateIndexRequest",
    "DeleteIndexRequest",
    "GetIndexRequest",
    "ListIndexesRequest",
    "ListIndexesResponse",
    "NearestNeighborSearchOperationMetadata",
    "RemoveDatapointsRequest",
    "RemoveDatapointsResponse",
    "UpdateIndexOperationMetadata",
    "UpdateIndexRequest",
    "UpsertDatapointsRequest",
    "UpsertDatapointsResponse",
    "AvroSource",
    "BigQueryDestination",
    "BigQuerySource",
    "ContainerRegistryDestination",
    "CsvDestination",
    "CsvSource",
    "GcsDestination",
    "GcsSource",
    "TFRecordDestination",
    "CancelBatchPredictionJobRequest",
    "CancelCustomJobRequest",
    "CancelDataLabelingJobRequest",
    "CancelHyperparameterTuningJobRequest",
    "CancelNasJobRequest",
    "CreateBatchPredictionJobRequest",
    "CreateCustomJobRequest",
    "CreateDataLabelingJobRequest",
    "CreateHyperparameterTuningJobRequest",
    "CreateModelDeploymentMonitoringJobRequest",
    "CreateNasJobRequest",
    "DeleteBatchPredictionJobRequest",
    "DeleteCustomJobRequest",
    "DeleteDataLabelingJobRequest",
    "DeleteHyperparameterTuningJobRequest",
    "DeleteModelDeploymentMonitoringJobRequest",
    "DeleteNasJobRequest",
    "GetBatchPredictionJobRequest",
    "GetCustomJobRequest",
    "GetDataLabelingJobRequest",
    "GetHyperparameterTuningJobRequest",
    "GetModelDeploymentMonitoringJobRequest",
    "GetNasJobRequest",
    "GetNasTrialDetailRequest",
    "ListBatchPredictionJobsRequest",
    "ListBatchPredictionJobsResponse",
    "ListCustomJobsRequest",
    "ListCustomJobsResponse",
    "ListDataLabelingJobsRequest",
    "ListDataLabelingJobsResponse",
    "ListHyperparameterTuningJobsRequest",
    "ListHyperparameterTuningJobsResponse",
    "ListModelDeploymentMonitoringJobsRequest",
    "ListModelDeploymentMonitoringJobsResponse",
    "ListNasJobsRequest",
    "ListNasJobsResponse",
    "ListNasTrialDetailsRequest",
    "ListNasTrialDetailsResponse",
    "PauseModelDeploymentMonitoringJobRequest",
    "ResumeModelDeploymentMonitoringJobRequest",
    "SearchModelDeploymentMonitoringStatsAnomaliesRequest",
    "SearchModelDeploymentMonitoringStatsAnomaliesResponse",
    "UpdateModelDeploymentMonitoringJobOperationMetadata",
    "UpdateModelDeploymentMonitoringJobRequest",
    "JobState",
    "LineageSubgraph",
    "AutomaticResources",
    "AutoscalingMetricSpec",
    "BatchDedicatedResources",
    "DedicatedResources",
    "DiskSpec",
    "MachineSpec",
    "NfsMount",
    "ResourcesConsumed",
    "ManualBatchTuningParameters",
    "MetadataSchema",
    "AddContextArtifactsAndExecutionsRequest",
    "AddContextArtifactsAndExecutionsResponse",
    "AddContextChildrenRequest",
    "AddContextChildrenResponse",
    "AddExecutionEventsRequest",
    "AddExecutionEventsResponse",
    "CreateArtifactRequest",
    "CreateContextRequest",
    "CreateExecutionRequest",
    "CreateMetadataSchemaRequest",
    "CreateMetadataStoreOperationMetadata",
    "CreateMetadataStoreRequest",
    "DeleteArtifactRequest",
    "DeleteContextRequest",
    "DeleteExecutionRequest",
    "DeleteMetadataStoreOperationMetadata",
    "DeleteMetadataStoreRequest",
    "GetArtifactRequest",
    "GetContextRequest",
    "GetExecutionRequest",
    "GetMetadataSchemaRequest",
    "GetMetadataStoreRequest",
    "ListArtifactsRequest",
    "ListArtifactsResponse",
    "ListContextsRequest",
    "ListContextsResponse",
    "ListExecutionsRequest",
    "ListExecutionsResponse",
    "ListMetadataSchemasRequest",
    "ListMetadataSchemasResponse",
    "ListMetadataStoresRequest",
    "ListMetadataStoresResponse",
    "PurgeArtifactsMetadata",
    "PurgeArtifactsRequest",
    "PurgeArtifactsResponse",
    "PurgeContextsMetadata",
    "PurgeContextsRequest",
    "PurgeContextsResponse",
    "PurgeExecutionsMetadata",
    "PurgeExecutionsRequest",
    "PurgeExecutionsResponse",
    "QueryArtifactLineageSubgraphRequest",
    "QueryContextLineageSubgraphRequest",
    "QueryExecutionInputsAndOutputsRequest",
    "RemoveContextChildrenRequest",
    "RemoveContextChildrenResponse",
    "UpdateArtifactRequest",
    "UpdateContextRequest",
    "UpdateExecutionRequest",
    "MetadataStore",
    "MigratableResource",
    "BatchMigrateResourcesOperationMetadata",
    "BatchMigrateResourcesRequest",
    "BatchMigrateResourcesResponse",
    "MigrateResourceRequest",
    "MigrateResourceResponse",
    "SearchMigratableResourcesRequest",
    "SearchMigratableResourcesResponse",
    "Model",
    "ModelContainerSpec",
    "ModelSourceInfo",
    "Port",
    "PredictSchemata",
    "ModelDeploymentMonitoringBigQueryTable",
    "ModelDeploymentMonitoringJob",
    "ModelDeploymentMonitoringObjectiveConfig",
    "ModelDeploymentMonitoringScheduleConfig",
    "ModelMonitoringStatsAnomalies",
    "ModelDeploymentMonitoringObjectiveType",
    "ModelEvaluation",
    "ModelEvaluationSlice",
    "ModelMonitoringAlertConfig",
    "ModelMonitoringObjectiveConfig",
    "SamplingStrategy",
    "ThresholdConfig",
    "BatchImportModelEvaluationSlicesRequest",
    "BatchImportModelEvaluationSlicesResponse",
    "CopyModelOperationMetadata",
    "CopyModelRequest",
    "CopyModelResponse",
    "DeleteModelRequest",
    "DeleteModelVersionRequest",
    "ExportModelOperationMetadata",
    "ExportModelRequest",
    "ExportModelResponse",
    "GetModelEvaluationRequest",
    "GetModelEvaluationSliceRequest",
    "GetModelRequest",
    "ImportModelEvaluationRequest",
    "ListModelEvaluationSlicesRequest",
    "ListModelEvaluationSlicesResponse",
    "ListModelEvaluationsRequest",
    "ListModelEvaluationsResponse",
    "ListModelsRequest",
    "ListModelsResponse",
    "ListModelVersionsRequest",
    "ListModelVersionsResponse",
    "MergeVersionAliasesRequest",
    "UpdateModelRequest",
    "UploadModelOperationMetadata",
    "UploadModelRequest",
    "UploadModelResponse",
    "NasJob",
    "NasJobOutput",
    "NasJobSpec",
    "NasTrial",
    "NasTrialDetail",
    "DeleteOperationMetadata",
    "GenericOperationMetadata",
    "PipelineFailurePolicy",
    "PipelineJob",
    "PipelineJobDetail",
    "PipelineTaskDetail",
    "PipelineTaskExecutorDetail",
    "PipelineTemplateMetadata",
    "CancelPipelineJobRequest",
    "CancelTrainingPipelineRequest",
    "CreatePipelineJobRequest",
    "CreateTrainingPipelineRequest",
    "DeletePipelineJobRequest",
    "DeleteTrainingPipelineRequest",
    "GetPipelineJobRequest",
    "GetTrainingPipelineRequest",
    "ListPipelineJobsRequest",
    "ListPipelineJobsResponse",
    "ListTrainingPipelinesRequest",
    "ListTrainingPipelinesResponse",
    "PipelineState",
    "ExplainRequest",
    "ExplainResponse",
    "PredictRequest",
    "PredictResponse",
    "RawPredictRequest",
    "SavedQuery",
    "PrivateServiceConnectConfig",
    "SpecialistPool",
    "CreateSpecialistPoolOperationMetadata",
    "CreateSpecialistPoolRequest",
    "DeleteSpecialistPoolRequest",
    "GetSpecialistPoolRequest",
    "ListSpecialistPoolsRequest",
    "ListSpecialistPoolsResponse",
    "UpdateSpecialistPoolOperationMetadata",
    "UpdateSpecialistPoolRequest",
    "Measurement",
    "Study",
    "StudySpec",
    "Trial",
    "Tensorboard",
    "Scalar",
    "TensorboardBlob",
    "TensorboardBlobSequence",
    "TensorboardTensor",
    "TimeSeriesData",
    "TimeSeriesDataPoint",
    "TensorboardExperiment",
    "TensorboardRun",
    "BatchCreateTensorboardRunsRequest",
    "BatchCreateTensorboardRunsResponse",
    "BatchCreateTensorboardTimeSeriesRequest",
    "BatchCreateTensorboardTimeSeriesResponse",
    "BatchReadTensorboardTimeSeriesDataRequest",
    "BatchReadTensorboardTimeSeriesDataResponse",
    "CreateTensorboardExperimentRequest",
    "CreateTensorboardOperationMetadata",
    "CreateTensorboardRequest",
    "CreateTensorboardRunRequest",
    "CreateTensorboardTimeSeriesRequest",
    "DeleteTensorboardExperimentRequest",
    "DeleteTensorboardRequest",
    "DeleteTensorboardRunRequest",
    "DeleteTensorboardTimeSeriesRequest",
    "ExportTensorboardTimeSeriesDataRequest",
    "ExportTensorboardTimeSeriesDataResponse",
    "GetTensorboardExperimentRequest",
    "GetTensorboardRequest",
    "GetTensorboardRunRequest",
    "GetTensorboardTimeSeriesRequest",
    "ListTensorboardExperimentsRequest",
    "ListTensorboardExperimentsResponse",
    "ListTensorboardRunsRequest",
    "ListTensorboardRunsResponse",
    "ListTensorboardsRequest",
    "ListTensorboardsResponse",
    "ListTensorboardTimeSeriesRequest",
    "ListTensorboardTimeSeriesResponse",
    "ReadTensorboardBlobDataRequest",
    "ReadTensorboardBlobDataResponse",
    "ReadTensorboardTimeSeriesDataRequest",
    "ReadTensorboardTimeSeriesDataResponse",
    "ReadTensorboardUsageRequest",
    "ReadTensorboardUsageResponse",
    "UpdateTensorboardExperimentRequest",
    "UpdateTensorboardOperationMetadata",
    "UpdateTensorboardRequest",
    "UpdateTensorboardRunRequest",
    "UpdateTensorboardTimeSeriesRequest",
    "WriteTensorboardExperimentDataRequest",
    "WriteTensorboardExperimentDataResponse",
    "WriteTensorboardRunDataRequest",
    "WriteTensorboardRunDataResponse",
    "TensorboardTimeSeries",
    "FilterSplit",
    "FractionSplit",
    "InputDataConfig",
    "PredefinedSplit",
    "StratifiedSplit",
    "TimestampSplit",
    "TrainingPipeline",
    "BoolArray",
    "DoubleArray",
    "Int64Array",
    "StringArray",
    "UnmanagedContainerModel",
    "UserActionReference",
    "Value",
    "AddTrialMeasurementRequest",
    "CheckTrialEarlyStoppingStateMetatdata",
    "CheckTrialEarlyStoppingStateRequest",
    "CheckTrialEarlyStoppingStateResponse",
    "CompleteTrialRequest",
    "CreateStudyRequest",
    "CreateTrialRequest",
    "DeleteStudyRequest",
    "DeleteTrialRequest",
    "GetStudyRequest",
    "GetTrialRequest",
    "ListOptimalTrialsRequest",
    "ListOptimalTrialsResponse",
    "ListStudiesRequest",
    "ListStudiesResponse",
    "ListTrialsRequest",
    "ListTrialsResponse",
    "LookupStudyRequest",
    "StopTrialRequest",
    "SuggestTrialsMetadata",
    "SuggestTrialsRequest",
    "SuggestTrialsResponse",
)



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
import functools
import re
from typing import (
    Dict,
    Mapping,
    MutableMapping,
    MutableSequence,
    Optional,
    Sequence,
    Tuple,
    Type,
    Union,
)

from google.cloud.aiplatform_v1beta1 import gapic_version as package_version

from google.api_core.client_options import ClientOptions
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

try:
    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.Retry, object]  # type: ignore

from google.api_core import operation  # type: ignore
from google.api_core import operation_async  # type: ignore
from google.cloud.aiplatform_v1beta1.services.vizier_service import pagers
from google.cloud.aiplatform_v1beta1.types import study
from google.cloud.aiplatform_v1beta1.types import study as gca_study
from google.cloud.aiplatform_v1beta1.types import vizier_service
from google.cloud.location import locations_pb2  # type: ignore
from google.iam.v1 import iam_policy_pb2  # type: ignore
from google.iam.v1 import policy_pb2  # type: ignore
from google.longrunning import operations_pb2
from google.protobuf import timestamp_pb2  # type: ignore
from .transports.base import VizierServiceTransport, DEFAULT_CLIENT_INFO
from .transports.grpc_asyncio import VizierServiceGrpcAsyncIOTransport
from .client import VizierServiceClient


class VizierServiceAsyncClient:
    """Vertex AI Vizier API.
    Vertex AI Vizier is a service to solve blackbox optimization
    problems, such as tuning machine learning hyperparameters and
    searching over deep learning architectures.
    """

    _client: VizierServiceClient

    DEFAULT_ENDPOINT = VizierServiceClient.DEFAULT_ENDPOINT
    DEFAULT_MTLS_ENDPOINT = VizierServiceClient.DEFAULT_MTLS_ENDPOINT

    custom_job_path = staticmethod(VizierServiceClient.custom_job_path)
    parse_custom_job_path = staticmethod(VizierServiceClient.parse_custom_job_path)
    study_path = staticmethod(VizierServiceClient.study_path)
    parse_study_path = staticmethod(VizierServiceClient.parse_study_path)
    trial_path = staticmethod(VizierServiceClient.trial_path)
    parse_trial_path = staticmethod(VizierServiceClient.parse_trial_path)
    common_billing_account_path = staticmethod(
        VizierServiceClient.common_billing_account_path
    )
    parse_common_billing_account_path = staticmethod(
        VizierServiceClient.parse_common_billing_account_path
    )
    common_folder_path = staticmethod(VizierServiceClient.common_folder_path)
    parse_common_folder_path = staticmethod(
        VizierServiceClient.parse_common_folder_path
    )
    common_organization_path = staticmethod(
        VizierServiceClient.common_organization_path
    )
    parse_common_organization_path = staticmethod(
        VizierServiceClient.parse_common_organization_path
    )
    common_project_path = staticmethod(VizierServiceClient.common_project_path)
    parse_common_project_path = staticmethod(
        VizierServiceClient.parse_common_project_path
    )
    common_location_path = staticmethod(VizierServiceClient.common_location_path)
    parse_common_location_path = staticmethod(
        VizierServiceClient.parse_common_location_path
    )

    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            info.

        Args:
            info (dict): The service account private key info.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            VizierServiceAsyncClient: The constructed client.
        """
        return VizierServiceClient.from_service_account_info.__func__(VizierServiceAsyncClient, info, *args, **kwargs)  # type: ignore

    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            VizierServiceAsyncClient: The constructed client.
        """
        return VizierServiceClient.from_service_account_file.__func__(VizierServiceAsyncClient, filename, *args, **kwargs)  # type: ignore

    from_service_account_json = from_service_account_file

    @classmethod
    def get_mtls_endpoint_and_cert_source(
        cls, client_options: Optional[ClientOptions] = None
    ):
        """Return the API endpoint and client cert source for mutual TLS.

        The client cert source is determined in the following order:
        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
        client cert source is None.
        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
        default client cert source exists, use the default one; otherwise the client cert
        source is None.

        The API endpoint is determined in the following order:
        (1) if `client_options.api_endpoint` if provided, use the provided one.
        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
        default mTLS endpoint; if the environment variable is "never", use the default API
        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
        use the default API endpoint.

        More details can be found at https://google.aip.dev/auth/4114.

        Args:
            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                client. Only the `api_endpoint` and `client_cert_source` properties may be used
                in this method.

        Returns:
            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
                client cert source to use.

        Raises:
            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
        """
        return VizierServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore

    @property
    def transport(self) -> VizierServiceTransport:
        """Returns the transport used by the client instance.

        Returns:
            VizierServiceTransport: The transport used by the client instance.
        """
        return self._client.transport

    get_transport_class = functools.partial(
        type(VizierServiceClient).get_transport_class, type(VizierServiceClient)
    )

    def __init__(
        self,
        *,
        credentials: Optional[ga_credentials.Credentials] = None,
        transport: Union[str, VizierServiceTransport] = "grpc_asyncio",
        client_options: Optional[ClientOptions] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
    ) -> None:
        """Instantiates the vizier service client.

        Args:
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            transport (Union[str, ~.VizierServiceTransport]): The
                transport to use. If set to None, a transport is chosen
                automatically.
            client_options (ClientOptions): Custom options for the client. It
                won't take effect if a ``transport`` instance is provided.
                (1) The ``api_endpoint`` property can be used to override the
                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                environment variable can also be used to override the endpoint:
                "always" (always use the default mTLS endpoint), "never" (always
                use the default regular endpoint) and "auto" (auto switch to the
                default mTLS endpoint if client certificate is present, this is
                the default value). However, the ``api_endpoint`` property takes
                precedence if provided.
                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
                is "true", then the ``client_cert_source`` property can be used
                to provide client certificate for mutual TLS transport. If
                not provided, the default SSL client certificate will be used if
                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                set, no client certificate will be used.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                creation failed for any reason.
        """
        self._client = VizierServiceClient(
            credentials=credentials,
            transport=transport,
            client_options=client_options,
            client_info=client_info,
        )

    async def create_study(
        self,
        request: Optional[Union[vizier_service.CreateStudyRequest, dict]] = None,
        *,
        parent: Optional[str] = None,
        study: Optional[gca_study.Study] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> gca_study.Study:
        r"""Creates a Study. A resource name will be generated
        after creation of the Study.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_create_study():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                study = aiplatform_v1beta1.Study()
                study.display_name = "display_name_value"
                study.study_spec.metrics.metric_id = "metric_id_value"
                study.study_spec.metrics.goal = "MINIMIZE"
                study.study_spec.parameters.double_value_spec.min_value = 0.96
                study.study_spec.parameters.double_value_spec.max_value = 0.962
                study.study_spec.parameters.parameter_id = "parameter_id_value"

                request = aiplatform_v1beta1.CreateStudyRequest(
                    parent="parent_value",
                    study=study,
                )

                # Make the request
                response = await client.create_study(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.CreateStudyRequest, dict]]):
                The request object. Request message for
                [VizierService.CreateStudy][google.cloud.aiplatform.v1beta1.VizierService.CreateStudy].
            parent (:class:`str`):
                Required. The resource name of the Location to create
                the CustomJob in. Format:
                ``projects/{project}/locations/{location}``

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            study (:class:`google.cloud.aiplatform_v1beta1.types.Study`):
                Required. The Study configuration
                used to create the Study.

                This corresponds to the ``study`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.aiplatform_v1beta1.types.Study:
                A message representing a Study.
        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent, study])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = vizier_service.CreateStudyRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent
        if study is not None:
            request.study = study

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.create_study,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_study(
        self,
        request: Optional[Union[vizier_service.GetStudyRequest, dict]] = None,
        *,
        name: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> study.Study:
        r"""Gets a Study by name.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_get_study():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.GetStudyRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.get_study(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.GetStudyRequest, dict]]):
                The request object. Request message for
                [VizierService.GetStudy][google.cloud.aiplatform.v1beta1.VizierService.GetStudy].
            name (:class:`str`):
                Required. The name of the Study resource. Format:
                ``projects/{project}/locations/{location}/studies/{study}``

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.aiplatform_v1beta1.types.Study:
                A message representing a Study.
        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = vizier_service.GetStudyRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.get_study,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_studies(
        self,
        request: Optional[Union[vizier_service.ListStudiesRequest, dict]] = None,
        *,
        parent: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> pagers.ListStudiesAsyncPager:
        r"""Lists all the studies in a region for an associated
        project.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_list_studies():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.ListStudiesRequest(
                    parent="parent_value",
                )

                # Make the request
                page_result = client.list_studies(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.ListStudiesRequest, dict]]):
                The request object. Request message for
                [VizierService.ListStudies][google.cloud.aiplatform.v1beta1.VizierService.ListStudies].
            parent (:class:`str`):
                Required. The resource name of the Location to list the
                Study from. Format:
                ``projects/{project}/locations/{location}``

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.aiplatform_v1beta1.services.vizier_service.pagers.ListStudiesAsyncPager:
                Response message for
                   [VizierService.ListStudies][google.cloud.aiplatform.v1beta1.VizierService.ListStudies].

                Iterating over this object will yield results and
                resolve additional pages automatically.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = vizier_service.ListStudiesRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.list_studies,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.ListStudiesAsyncPager(
            method=rpc,
            request=request,
            response=response,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def delete_study(
        self,
        request: Optional[Union[vizier_service.DeleteStudyRequest, dict]] = None,
        *,
        name: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> None:
        r"""Deletes a Study.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_delete_study():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.DeleteStudyRequest(
                    name="name_value",
                )

                # Make the request
                await client.delete_study(request=request)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.DeleteStudyRequest, dict]]):
                The request object. Request message for
                [VizierService.DeleteStudy][google.cloud.aiplatform.v1beta1.VizierService.DeleteStudy].
            name (:class:`str`):
                Required. The name of the Study resource to be deleted.
                Format:
                ``projects/{project}/locations/{location}/studies/{study}``

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = vizier_service.DeleteStudyRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.delete_study,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

    async def lookup_study(
        self,
        request: Optional[Union[vizier_service.LookupStudyRequest, dict]] = None,
        *,
        parent: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> study.Study:
        r"""Looks a study up using the user-defined display_name field
        instead of the fully qualified resource name.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_lookup_study():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.LookupStudyRequest(
                    parent="parent_value",
                    display_name="display_name_value",
                )

                # Make the request
                response = await client.lookup_study(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.LookupStudyRequest, dict]]):
                The request object. Request message for
                [VizierService.LookupStudy][google.cloud.aiplatform.v1beta1.VizierService.LookupStudy].
            parent (:class:`str`):
                Required. The resource name of the Location to get the
                Study from. Format:
                ``projects/{project}/locations/{location}``

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.aiplatform_v1beta1.types.Study:
                A message representing a Study.
        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = vizier_service.LookupStudyRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.lookup_study,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def suggest_trials(
        self,
        request: Optional[Union[vizier_service.SuggestTrialsRequest, dict]] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> operation_async.AsyncOperation:
        r"""Adds one or more Trials to a Study, with parameter values
        suggested by Vertex AI Vizier. Returns a long-running operation
        associated with the generation of Trial suggestions. When this
        long-running operation succeeds, it will contain a
        [SuggestTrialsResponse][google.cloud.ml.v1.SuggestTrialsResponse].

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_suggest_trials():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.SuggestTrialsRequest(
                    parent="parent_value",
                    suggestion_count=1744,
                    client_id="client_id_value",
                )

                # Make the request
                operation = client.suggest_trials(request=request)

                print("Waiting for operation to complete...")

                response = (await operation).result()

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.SuggestTrialsRequest, dict]]):
                The request object. Request message for
                [VizierService.SuggestTrials][google.cloud.aiplatform.v1beta1.VizierService.SuggestTrials].
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.api_core.operation_async.AsyncOperation:
                An object representing a long-running operation.

                The result type for the operation will be :class:`google.cloud.aiplatform_v1beta1.types.SuggestTrialsResponse` Response message for
                   [VizierService.SuggestTrials][google.cloud.aiplatform.v1beta1.VizierService.SuggestTrials].

        """
        # Create or coerce a protobuf request object.
        request = vizier_service.SuggestTrialsRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.suggest_trials,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Wrap the response in an operation future.
        response = operation_async.from_gapic(
            response,
            self._client._transport.operations_client,
            vizier_service.SuggestTrialsResponse,
            metadata_type=vizier_service.SuggestTrialsMetadata,
        )

        # Done; return the response.
        return response

    async def create_trial(
        self,
        request: Optional[Union[vizier_service.CreateTrialRequest, dict]] = None,
        *,
        parent: Optional[str] = None,
        trial: Optional[study.Trial] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> study.Trial:
        r"""Adds a user provided Trial to a Study.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_create_trial():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.CreateTrialRequest(
                    parent="parent_value",
                )

                # Make the request
                response = await client.create_trial(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.CreateTrialRequest, dict]]):
                The request object. Request message for
                [VizierService.CreateTrial][google.cloud.aiplatform.v1beta1.VizierService.CreateTrial].
            parent (:class:`str`):
                Required. The resource name of the Study to create the
                Trial in. Format:
                ``projects/{project}/locations/{location}/studies/{study}``

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            trial (:class:`google.cloud.aiplatform_v1beta1.types.Trial`):
                Required. The Trial to create.
                This corresponds to the ``trial`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.aiplatform_v1beta1.types.Trial:
                A message representing a Trial. A
                Trial contains a unique set of
                Parameters that has been or will be
                evaluated, along with the objective
                metrics got by running the Trial.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent, trial])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = vizier_service.CreateTrialRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent
        if trial is not None:
            request.trial = trial

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.create_trial,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_trial(
        self,
        request: Optional[Union[vizier_service.GetTrialRequest, dict]] = None,
        *,
        name: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> study.Trial:
        r"""Gets a Trial.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_get_trial():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.GetTrialRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.get_trial(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.GetTrialRequest, dict]]):
                The request object. Request message for
                [VizierService.GetTrial][google.cloud.aiplatform.v1beta1.VizierService.GetTrial].
            name (:class:`str`):
                Required. The name of the Trial resource. Format:
                ``projects/{project}/locations/{location}/studies/{study}/trials/{trial}``

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.aiplatform_v1beta1.types.Trial:
                A message representing a Trial. A
                Trial contains a unique set of
                Parameters that has been or will be
                evaluated, along with the objective
                metrics got by running the Trial.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = vizier_service.GetTrialRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.get_trial,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_trials(
        self,
        request: Optional[Union[vizier_service.ListTrialsRequest, dict]] = None,
        *,
        parent: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> pagers.ListTrialsAsyncPager:
        r"""Lists the Trials associated with a Study.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_list_trials():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.ListTrialsRequest(
                    parent="parent_value",
                )

                # Make the request
                page_result = client.list_trials(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.ListTrialsRequest, dict]]):
                The request object. Request message for
                [VizierService.ListTrials][google.cloud.aiplatform.v1beta1.VizierService.ListTrials].
            parent (:class:`str`):
                Required. The resource name of the Study to list the
                Trial from. Format:
                ``projects/{project}/locations/{location}/studies/{study}``

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.aiplatform_v1beta1.services.vizier_service.pagers.ListTrialsAsyncPager:
                Response message for
                   [VizierService.ListTrials][google.cloud.aiplatform.v1beta1.VizierService.ListTrials].

                Iterating over this object will yield results and
                resolve additional pages automatically.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = vizier_service.ListTrialsRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.list_trials,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.ListTrialsAsyncPager(
            method=rpc,
            request=request,
            response=response,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def add_trial_measurement(
        self,
        request: Optional[
            Union[vizier_service.AddTrialMeasurementRequest, dict]
        ] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> study.Trial:
        r"""Adds a measurement of the objective metrics to a
        Trial. This measurement is assumed to have been taken
        before the Trial is complete.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_add_trial_measurement():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.AddTrialMeasurementRequest(
                    trial_name="trial_name_value",
                )

                # Make the request
                response = await client.add_trial_measurement(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.AddTrialMeasurementRequest, dict]]):
                The request object. Request message for
                [VizierService.AddTrialMeasurement][google.cloud.aiplatform.v1beta1.VizierService.AddTrialMeasurement].
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.aiplatform_v1beta1.types.Trial:
                A message representing a Trial. A
                Trial contains a unique set of
                Parameters that has been or will be
                evaluated, along with the objective
                metrics got by running the Trial.

        """
        # Create or coerce a protobuf request object.
        request = vizier_service.AddTrialMeasurementRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.add_trial_measurement,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata(
                (("trial_name", request.trial_name),)
            ),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def complete_trial(
        self,
        request: Optional[Union[vizier_service.CompleteTrialRequest, dict]] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> study.Trial:
        r"""Marks a Trial as complete.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_complete_trial():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.CompleteTrialRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.complete_trial(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.CompleteTrialRequest, dict]]):
                The request object. Request message for
                [VizierService.CompleteTrial][google.cloud.aiplatform.v1beta1.VizierService.CompleteTrial].
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.aiplatform_v1beta1.types.Trial:
                A message representing a Trial. A
                Trial contains a unique set of
                Parameters that has been or will be
                evaluated, along with the objective
                metrics got by running the Trial.

        """
        # Create or coerce a protobuf request object.
        request = vizier_service.CompleteTrialRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.complete_trial,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def delete_trial(
        self,
        request: Optional[Union[vizier_service.DeleteTrialRequest, dict]] = None,
        *,
        name: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> None:
        r"""Deletes a Trial.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_delete_trial():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.DeleteTrialRequest(
                    name="name_value",
                )

                # Make the request
                await client.delete_trial(request=request)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.DeleteTrialRequest, dict]]):
                The request object. Request message for
                [VizierService.DeleteTrial][google.cloud.aiplatform.v1beta1.VizierService.DeleteTrial].
            name (:class:`str`):
                Required. The Trial's name. Format:
                ``projects/{project}/locations/{location}/studies/{study}/trials/{trial}``

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = vizier_service.DeleteTrialRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.delete_trial,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

    async def check_trial_early_stopping_state(
        self,
        request: Optional[
            Union[vizier_service.CheckTrialEarlyStoppingStateRequest, dict]
        ] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> operation_async.AsyncOperation:
        r"""Checks whether a Trial should stop or not. Returns a
        long-running operation. When the operation is successful, it
        will contain a
        [CheckTrialEarlyStoppingStateResponse][google.cloud.ml.v1.CheckTrialEarlyStoppingStateResponse].

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_check_trial_early_stopping_state():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.CheckTrialEarlyStoppingStateRequest(
                    trial_name="trial_name_value",
                )

                # Make the request
                operation = client.check_trial_early_stopping_state(request=request)

                print("Waiting for operation to complete...")

                response = (await operation).result()

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.CheckTrialEarlyStoppingStateRequest, dict]]):
                The request object. Request message for
                [VizierService.CheckTrialEarlyStoppingState][google.cloud.aiplatform.v1beta1.VizierService.CheckTrialEarlyStoppingState].
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.api_core.operation_async.AsyncOperation:
                An object representing a long-running operation.

                The result type for the operation will be :class:`google.cloud.aiplatform_v1beta1.types.CheckTrialEarlyStoppingStateResponse` Response message for
                   [VizierService.CheckTrialEarlyStoppingState][google.cloud.aiplatform.v1beta1.VizierService.CheckTrialEarlyStoppingState].

        """
        # Create or coerce a protobuf request object.
        request = vizier_service.CheckTrialEarlyStoppingStateRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.check_trial_early_stopping_state,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata(
                (("trial_name", request.trial_name),)
            ),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Wrap the response in an operation future.
        response = operation_async.from_gapic(
            response,
            self._client._transport.operations_client,
            vizier_service.CheckTrialEarlyStoppingStateResponse,
            metadata_type=vizier_service.CheckTrialEarlyStoppingStateMetatdata,
        )

        # Done; return the response.
        return response

    async def stop_trial(
        self,
        request: Optional[Union[vizier_service.StopTrialRequest, dict]] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> study.Trial:
        r"""Stops a Trial.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_stop_trial():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.StopTrialRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.stop_trial(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.StopTrialRequest, dict]]):
                The request object. Request message for
                [VizierService.StopTrial][google.cloud.aiplatform.v1beta1.VizierService.StopTrial].
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.aiplatform_v1beta1.types.Trial:
                A message representing a Trial. A
                Trial contains a unique set of
                Parameters that has been or will be
                evaluated, along with the objective
                metrics got by running the Trial.

        """
        # Create or coerce a protobuf request object.
        request = vizier_service.StopTrialRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.stop_trial,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_optimal_trials(
        self,
        request: Optional[Union[vizier_service.ListOptimalTrialsRequest, dict]] = None,
        *,
        parent: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> vizier_service.ListOptimalTrialsResponse:
        r"""Lists the pareto-optimal Trials for multi-objective Study or the
        optimal Trials for single-objective Study. The definition of
        pareto-optimal can be checked in wiki page.
        https://en.wikipedia.org/wiki/Pareto_efficiency

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import aiplatform_v1beta1

            async def sample_list_optimal_trials():
                # Create a client
                client = aiplatform_v1beta1.VizierServiceAsyncClient()

                # Initialize request argument(s)
                request = aiplatform_v1beta1.ListOptimalTrialsRequest(
                    parent="parent_value",
                )

                # Make the request
                response = await client.list_optimal_trials(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.aiplatform_v1beta1.types.ListOptimalTrialsRequest, dict]]):
                The request object. Request message for
                [VizierService.ListOptimalTrials][google.cloud.aiplatform.v1beta1.VizierService.ListOptimalTrials].
            parent (:class:`str`):
                Required. The name of the Study that
                the optimal Trial belongs to.

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.aiplatform_v1beta1.types.ListOptimalTrialsResponse:
                Response message for
                   [VizierService.ListOptimalTrials][google.cloud.aiplatform.v1beta1.VizierService.ListOptimalTrials].

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = vizier_service.ListOptimalTrialsRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.list_optimal_trials,
            default_timeout=5.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_operations(
        self,
        request: Optional[operations_pb2.ListOperationsRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> operations_pb2.ListOperationsResponse:
        r"""Lists operations that match the specified filter in the request.

        Args:
            request (:class:`~.operations_pb2.ListOperationsRequest`):
                The request object. Request message for
                `ListOperations` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                    if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            ~.operations_pb2.ListOperationsResponse:
                Response message for ``ListOperations`` method.
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = operations_pb2.ListOperationsRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._client._transport.list_operations,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_operation(
        self,
        request: Optional[operations_pb2.GetOperationRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> operations_pb2.Operation:
        r"""Gets the latest state of a long-running operation.

        Args:
            request (:class:`~.operations_pb2.GetOperationRequest`):
                The request object. Request message for
                `GetOperation` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                    if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            ~.operations_pb2.Operation:
                An ``Operation`` object.
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = operations_pb2.GetOperationRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._client._transport.get_operation,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def delete_operation(
        self,
        request: Optional[operations_pb2.DeleteOperationRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> None:
        r"""Deletes a long-running operation.

        This method indicates that the client is no longer interested
        in the operation result. It does not cancel the operation.
        If the server doesn't support this method, it returns
        `google.rpc.Code.UNIMPLEMENTED`.

        Args:
            request (:class:`~.operations_pb2.DeleteOperationRequest`):
                The request object. Request message for
                `DeleteOperation` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                    if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            None
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = operations_pb2.DeleteOperationRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._client._transport.delete_operation,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

    async def cancel_operation(
        self,
        request: Optional[operations_pb2.CancelOperationRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> None:
        r"""Starts asynchronous cancellation on a long-running operation.

        The server makes a best effort to cancel the operation, but success
        is not guaranteed.  If the server doesn't support this method, it returns
        `google.rpc.Code.UNIMPLEMENTED`.

        Args:
            request (:class:`~.operations_pb2.CancelOperationRequest`):
                The request object. Request message for
                `CancelOperation` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                    if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            None
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = operations_pb2.CancelOperationRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._client._transport.cancel_operation,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

    async def wait_operation(
        self,
        request: Optional[operations_pb2.WaitOperationRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> operations_pb2.Operation:
        r"""Waits until the specified long-running operation is done or reaches at most
        a specified timeout, returning the latest state.

        If the operation is already done, the latest state is immediately returned.
        If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC
        timeout is used.  If the server does not support this method, it returns
        `google.rpc.Code.UNIMPLEMENTED`.

        Args:
            request (:class:`~.operations_pb2.WaitOperationRequest`):
                The request object. Request message for
                `WaitOperation` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                    if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            ~.operations_pb2.Operation:
                An ``Operation`` object.
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = operations_pb2.WaitOperationRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._client._transport.wait_operation,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def set_iam_policy(
        self,
        request: Optional[iam_policy_pb2.SetIamPolicyRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> policy_pb2.Policy:
        r"""Sets the IAM access control policy on the specified function.

        Replaces any existing policy.

        Args:
            request (:class:`~.iam_policy_pb2.SetIamPolicyRequest`):
                The request object. Request message for `SetIamPolicy`
                method.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            ~.policy_pb2.Policy:
                Defines an Identity and Access Management (IAM) policy.
                It is used to specify access control policies for Cloud
                Platform resources.
                A ``Policy`` is a collection of ``bindings``. A
                ``binding`` binds one or more ``members`` to a single
                ``role``. Members can be user accounts, service
                accounts, Google groups, and domains (such as G Suite).
                A ``role`` is a named list of permissions (defined by
                IAM or configured by users). A ``binding`` can
                optionally specify a ``condition``, which is a logic
                expression that further constrains the role binding
                based on attributes about the request and/or target
                resource.

                **JSON Example**

                ::

                    {
                      "bindings": [
                        {
                          "role": "roles/resourcemanager.organizationAdmin",
                          "members": [
                            "user:mike@example.com",
                            "group:admins@example.com",
                            "domain:google.com",
                            "serviceAccount:my-project-id@appspot.gserviceaccount.com"
                          ]
                        },
                        {
                          "role": "roles/resourcemanager.organizationViewer",
                          "members": ["user:eve@example.com"],
                          "condition": {
                            "title": "expirable access",
                            "description": "Does not grant access after Sep 2020",
                            "expression": "request.time <
                            timestamp('2020-10-01T00:00:00.000Z')",
                          }
                        }
                      ]
                    }

                **YAML Example**

                ::

                    bindings:
                    - members:
                      - user:mike@example.com
                      - group:admins@example.com
                      - domain:google.com
                      - serviceAccount:my-project-id@appspot.gserviceaccount.com
                      role: roles/resourcemanager.organizationAdmin
                    - members:
                      - user:eve@example.com
                      role: roles/resourcemanager.organizationViewer
                      condition:
                        title: expirable access
                        description: Does not grant access after Sep 2020
                        expression: request.time < timestamp('2020-10-01T00:00:00.000Z')

                For a description of IAM and its features, see the `IAM
                developer's
                guide <https://cloud.google.com/iam/docs>`__.
        """
        # Create or coerce a protobuf request object.

        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = iam_policy_pb2.SetIamPolicyRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._client._transport.set_iam_policy,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("resource", request.resource),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_iam_policy(
        self,
        request: Optional[iam_policy_pb2.GetIamPolicyRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> policy_pb2.Policy:
        r"""Gets the IAM access control policy for a function.

        Returns an empty policy if the function exists and does not have a
        policy set.

        Args:
            request (:class:`~.iam_policy_pb2.GetIamPolicyRequest`):
                The request object. Request message for `GetIamPolicy`
                method.
            retry (google.api_core.retry.Retry): Designation of what errors, if
                any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            ~.policy_pb2.Policy:
                Defines an Identity and Access Management (IAM) policy.
                It is used to specify access control policies for Cloud
                Platform resources.
                A ``Policy`` is a collection of ``bindings``. A
                ``binding`` binds one or more ``members`` to a single
                ``role``. Members can be user accounts, service
                accounts, Google groups, and domains (such as G Suite).
                A ``role`` is a named list of permissions (defined by
                IAM or configured by users). A ``binding`` can
                optionally specify a ``condition``, which is a logic
                expression that further constrains the role binding
                based on attributes about the request and/or target
                resource.

                **JSON Example**

                ::

                    {
                      "bindings": [
                        {
                          "role": "roles/resourcemanager.organizationAdmin",
                          "members": [
                            "user:mike@example.com",
                            "group:admins@example.com",
                            "domain:google.com",
                            "serviceAccount:my-project-id@appspot.gserviceaccount.com"
                          ]
                        },
                        {
                          "role": "roles/resourcemanager.organizationViewer",
                          "members": ["user:eve@example.com"],
                          "condition": {
                            "title": "expirable access",
                            "description": "Does not grant access after Sep 2020",
                            "expression": "request.time <
                            timestamp('2020-10-01T00:00:00.000Z')",
                          }
                        }
                      ]
                    }

                **YAML Example**

                ::

                    bindings:
                    - members:
                      - user:mike@example.com
                      - group:admins@example.com
                      - domain:google.com
                      - serviceAccount:my-project-id@appspot.gserviceaccount.com
                      role: roles/resourcemanager.organizationAdmin
                    - members:
                      - user:eve@example.com
                      role: roles/resourcemanager.organizationViewer
                      condition:
                        title: expirable access
                        description: Does not grant access after Sep 2020
                        expression: request.time < timestamp('2020-10-01T00:00:00.000Z')

                For a description of IAM and its features, see the `IAM
                developer's
                guide <https://cloud.google.com/iam/docs>`__.
        """
        # Create or coerce a protobuf request object.

        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = iam_policy_pb2.GetIamPolicyRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._client._transport.get_iam_policy,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("resource", request.resource),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def test_iam_permissions(
        self,
        request: Optional[iam_policy_pb2.TestIamPermissionsRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> iam_policy_pb2.TestIamPermissionsResponse:
        r"""Tests the specified IAM permissions against the IAM access control
            policy for a function.

        If the function does not exist, this will return an empty set
        of permissions, not a NOT_FOUND error.

        Args:
            request (:class:`~.iam_policy_pb2.TestIamPermissionsRequest`):
                The request object. Request message for
                `TestIamPermissions` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                 if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            ~.iam_policy_pb2.TestIamPermissionsResponse:
                Response message for ``TestIamPermissions`` method.
        """
        # Create or coerce a protobuf request object.

        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = iam_policy_pb2.TestIamPermissionsRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._client._transport.test_iam_permissions,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("resource", request.resource),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_location(
        self,
        request: Optional[locations_pb2.GetLocationRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> locations_pb2.Location:
        r"""Gets information about a location.

        Args:
            request (:class:`~.location_pb2.GetLocationRequest`):
                The request object. Request message for
                `GetLocation` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                 if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            ~.location_pb2.Location:
                Location object.
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = locations_pb2.GetLocationRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._client._transport.get_location,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_locations(
        self,
        request: Optional[locations_pb2.ListLocationsRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> locations_pb2.ListLocationsResponse:
        r"""Lists information about the supported locations for this service.

        Args:
            request (:class:`~.location_pb2.ListLocationsRequest`):
                The request object. Request message for
                `ListLocations` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                 if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            ~.location_pb2.ListLocationsResponse:
                Response message for ``ListLocations`` method.
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = locations_pb2.ListLocationsRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._client._transport.list_locations,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def __aenter__(self):
        return self

    async def __aexit__(self, exc_type, exc, tb):
        await self.transport.close()


DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


__all__ = ("VizierServiceAsyncClient",)



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.aiplatform.v1beta1",
    manifest={
        "TensorboardRun",
    },
)


class TensorboardRun(proto.Message):
    r"""TensorboardRun maps to a specific execution of a training job
    with a given set of hyperparameter values, model definition,
    dataset, etc

    Attributes:
        name (str):
            Output only. Name of the TensorboardRun. Format:
            ``projects/{project}/locations/{location}/tensorboards/{tensorboard}/experiments/{experiment}/runs/{run}``
        display_name (str):
            Required. User provided name of this
            TensorboardRun. This value must be unique among
            all TensorboardRuns belonging to the same parent
            TensorboardExperiment.
        description (str):
            Description of this TensorboardRun.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when this
            TensorboardRun was created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when this
            TensorboardRun was last updated.
        labels (MutableMapping[str, str]):
            The labels with user-defined metadata to organize your
            TensorboardRuns.

            This field will be used to filter and visualize Runs in the
            Tensorboard UI. For example, a Vertex AI training job can
            set a label aiplatform.googleapis.com/training_job_id=xxxxx
            to all the runs created within that job. An end user can set
            a label experiment_id=xxxxx for all the runs produced in a
            Jupyter notebook. These runs can be grouped by a label value
            and visualized together in the Tensorboard UI.

            Label keys and values can be no longer than 64 characters
            (Unicode codepoints), can only contain lowercase letters,
            numeric characters, underscores and dashes. International
            characters are allowed. No more than 64 user labels can be
            associated with one TensorboardRun (System labels are
            excluded).

            See https://goo.gl/xmQnxf for more information and examples
            of labels. System reserved label keys are prefixed with
            "aiplatform.googleapis.com/" and are immutable.
        etag (str):
            Used to perform a consistent
            read-modify-write updates. If not set, a blind
            "overwrite" update happens.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=8,
    )
    etag: str = proto.Field(
        proto.STRING,
        number=9,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-

# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from typing import Optional, List
from google.cloud.aiplatform_v1.types import (
    model_monitoring as gca_model_monitoring_v1,
)

# TODO(b/242108750): remove temporary logic once model monitoring for batch prediction is GA
from google.cloud.aiplatform_v1beta1.types import (
    model_monitoring as gca_model_monitoring_v1beta1,
)

gca_model_monitoring = gca_model_monitoring_v1


class EmailAlertConfig:
    def __init__(
        self, user_emails: List[str] = [], enable_logging: Optional[bool] = False
    ):
        """Initializer for EmailAlertConfig.

        Args:
            user_emails (List[str]):
                The email addresses to send the alert to.
            enable_logging (bool):
                Optional. Defaults to False. Streams detected anomalies to Cloud Logging. The anomalies will be
                put into json payload encoded from proto
                [google.cloud.aiplatform.logging.ModelMonitoringAnomaliesLogEntry][].
                This can be further sync'd to Pub/Sub or any other services
                supported by Cloud Logging.
        """
        self.enable_logging = enable_logging
        self.user_emails = user_emails
        self._config_for_bp = False

    # TODO(b/242108750): remove temporary logic once model monitoring for batch prediction is GA
    def as_proto(self) -> gca_model_monitoring.ModelMonitoringAlertConfig:
        """Converts EmailAlertConfig to a proto message.

        Returns:
            The GAPIC representation of the email alert config.
        """
        if self._config_for_bp:
            gca_model_monitoring = gca_model_monitoring_v1beta1
        else:
            gca_model_monitoring = gca_model_monitoring_v1
        user_email_alert_config = (
            gca_model_monitoring.ModelMonitoringAlertConfig.EmailAlertConfig(
                user_emails=self.user_emails
            )
        )
        return gca_model_monitoring.ModelMonitoringAlertConfig(
            email_alert_config=user_email_alert_config,
            enable_logging=self.enable_logging,
        )



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.aiplatform.v1",
    manifest={
        "EncryptionSpec",
    },
)


class EncryptionSpec(proto.Message):
    r"""Represents a customer-managed encryption key spec that can be
    applied to a top-level resource.

    Attributes:
        kms_key_name (str):
            Required. The Cloud KMS resource identifier of the customer
            managed encryption key used to protect a resource. Has the
            form:
            ``projects/my-project/locations/my-region/keyRings/my-kr/cryptoKeys/my-key``.
            The key needs to be in the same region as where the compute
            resource is created.
    """

    kms_key_name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
